tonalitytools.diatonic_interval_class_segment_to_chord_quality_string
=====================================================================

.. autofunction:: abjad.tools.tonalitytools.diatonic_interval_class_segment_to_chord_quality_string.diatonic_interval_class_segment_to_chord_quality_string
